@@ -21,5 +21,5 @@
 ###################################################################
 
 get.all.simple.paths.pp <- function(vect) {
-  .Call(C_R_igraph_get_all_simple_paths_pp, vect)
+  .Call(R_igraph_get_all_simple_paths_pp, vect)
 }
